#ifndef MOD_H
#define MOD_H

/*
 * Copyright (c) Abraham vd Merwe <abz@blio.com>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *	  notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *	  notice, this list of conditions and the following disclaimer in the
 *	  documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the author nor the names of other contributors
 *	  may be used to endorse or promote products derived from this software
 *	  without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include <tinysnmp/agent/odb.h>
#include <tinysnmp/compat/inttypes.h>

/*
 * Open all modules found in module path `path''. All regular files ending
 * with .so extentions are considered modules.
 *
 * Returns 0 if successful, or -1 if no modules could be loaded. The function
 * logs all errors and warnings automatically via the log subsystem.
 */
extern int mod_open (const char *path,const char *confdir);

/*
 * Clear the dirty flags on all loaded modules. If these flags are set,
 * no ObjectID's will be updated by the mod_update() function.
 */
extern void mod_clear ();

/*
 * If the specified ObjectID falls into one of the ObjectID ranges
 * which are exported by any of the loaded modules, and if that module's
 * dirty flag is not set, update that exported ObjectID range.
 *
 * Returns 0 if successful, -1 if some error occurred. The function
 * logs all errors and warnings automatically via the log subsystem.
 */
extern int mod_update (const uint32_t *oid);

/*
 * If the specified ObjectID falls into one of the ObjectID ranges
 * which are exported by any of the loaded modules, then (if the
 * dirty flags of the modules in question are not set), then the
 * ObjectID's of that module and the one that lexographically succeeds
 * it (if any) are also updated.
 *
 * Returns 0 if successful, -1 if some error occurred. The function
 * logs all errors and warnings automatically via the log subsystem.
 */
extern int mod_update_next (const uint32_t *oid);

#endif	/* #ifndef MOD_H */
