#ifndef SNMP_H
#define SNMP_H

/*
 * Copyright (c) Abraham vd Merwe <abz@blio.com>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *	  notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *	  notice, this list of conditions and the following disclaimer in the
 *	  documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the author nor the names of other contributors
 *	  may be used to endorse or promote products derived from this software
 *	  without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include <ber/ber.h>

#include <tinysnmp/tinysnmp.h>
#include <tinysnmp/compat/inttypes.h>

enum
{
   noError    = 0,
   tooBig     = 1,
   noSuchName = 2,
   badValue   = 3,
   readOnly   = 4,
   genErr     = 5
};

#define noError		noError
#define tooBig		tooBig
#define noSuchName	noSuchName
#define badValue	badValue
#define readOnly	readOnly
#define genErr		genErr

/*
 * Encode a GetResponse-PDU packet.
 *
 *      e           the buffer (see BER library)
 *      pdu         structure containing all the PDU data that should be encoded
 *      status      Error Status (see RFC 1157)
 *      index       Error Index (see RFC 1157)
 *
 * Returns 0 if successful, -1 if the message couldn't fit into the buffer or
 * if any of the ObjectID modules could not be updated.
 */
extern int encode_get_response (ber_t *e,const snmp_pdu_t *pdu,uint8_t status,uint32_t index);

/*
 * Decode GetRequest-PDU or GetNextRequest-PDU.
 *
 *      d           the buffer (see BER library)
 *      pdu         structure containing all the PDU data that were decoded
 *
 * Returns 0 if successful, -1 if some error occurred. Check errno to see
 * what error occurred. The following errors is possible:
 *
 *      ENOMEM      Out of memory
 *      EINVAL      The packet is a valid SNMP packet, but either some of the error
 *                  flags is set or it is an unsupported SNMP version or we were
 *                  unable to decode a tag properly
 */
extern int decode_pdu (snmp_pdu_t *pdu,ber_t *d);

#endif	/* #ifndef SNMP_H */
