
/*
 * Copyright (c) Abraham vd Merwe <abz@blio.com>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *	  notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *	  notice, this list of conditions and the following disclaimer in the
 *	  documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the author nor the names of other contributors
 *	  may be used to endorse or promote products derived from this software
 *	  without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include <sys/types.h>
#include <sys/sysctl.h>
#include <sys/vmmeter.h>
#include <fcntl.h>
#include <kvm.h>
#include <nlist.h>
#include <unistd.h>
#include <stddef.h>
#include <stdint.h>

#include "meminfo.h"

/*
 * Works for FreeBSD 2.2.x, 3.x, 4.x, and probably FreeBSD 2.1.x
 *
 * I copied (and modified) this code from a ``free'' implementation I
 * wrote a couple of years ago. Right now I don't have access to a
 * FreeBSD box, so this is all untested of course...
 */

int getmeminfo (struct meminfo *info)
{
   uint64_t pagesize = getpagesize ();
   int bufspace,mib[2];
   size_t len;
   struct vmmeter sum;
   kvm_t *kd;
   static struct nlist nl[] =
	 {
		{ "_cnt" },
		{ "_bufspace" },
		{ NULL }
	 };

   memset (info,0L,sizeof (struct meminfo));

   if ((kd = kvm_open (NULL,NULL,NULL,O_RDONLY,"kvm_open")) == NULL)
	 return (-1);

   mib[0] = CTL_HW;
   mib[1] = HW_PHYSMEM;
   len = sizeof (info->mem_total);
   if (sysctl (mib,2,&info->mem_total,&len,NULL,0) < 0 ||
	   kvm_nlist (kd,nl) < 0 ||
	   kvm_read (kd,nl[0].n_value,(void *) &sum,sizeof (sum)) != sizeof (sum) ||
	   kvm_read (kd,nl[1].n_value,(void *) &bufspace,sizeof (bufspace)) != sizeof (bufspace))
	 {
		kvm_close (kd);
		return (-1);
	 }

   kvm_close (kd);

   info->mem_cache = (uint64_t) sum.v_cache_count * pagesize;
   info->mem_buffer = bufspace;
   info->mem_free = (uint64_t) sum.v_free_count * pagesize;

   return (0);
}

int getswapinfo (struct swapinfo *info)
{
   kvm_t *kd;
   struct kvm_swap swapinfo;
   uint64_t pagesize = getpagesize ()

   memset (info,0L,sizeof (struct swapinfo));

   if ((kd = kvm_open (NULL,NULL,NULL,O_RDONLY,"kvm_open")) == NULL)
	 return (-1);

   if (kvm_getswapinfo (kd,&swapinfo,1,0) < 0)
	 {
		kvm_close (kd);
		return (-1);
	 }

   kvm_close (kd);

   info->swap_total = (uint64_t) swapinfo.ksw_total * pagesize;
   info->swap_free = (uint64_t) (swapinfo.ksw_total - swapinfo.ksw_used) * pagesize;

   return (0);
}

