#ifndef IPC_H
#define IPC_H

/*
 * Copyright (c) Abraham vd Merwe <abz@blio.com>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *	  notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *	  notice, this list of conditions and the following disclaimer in the
 *	  documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the author nor the names of other contributors
 *	  may be used to endorse or promote products derived from this software
 *	  without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include <tinysnmp/compat/inttypes.h>

#include <ipc.h>

#include "config.h"

/*
 * receive a command from the client. the command is stored in ``cmd''
 * and if the retrieved command also includes a client index, said
 * index is stored in ``client''. returns 0 if successful, -1 if some
 * error occurred. the function automatically logs errors at the
 * LOG_WARNING level.
 */
extern int ipc_get (int fd,uint32_t *cmd,uint32_t *client);

/*
 * send the number of clients to the client. returns 0 if successful,
 * -1 if some error occurred. the function automatically logs errors
 * at the LOG_WARNING level.
 */
extern int ipc_put_clients (int fd,uint32_t n);

/*
 * send the client information of specified client to the client (that
 * sounds confusing, doesn't it *g*). returns 0 if successful, -1 if
 * some error occurred. the function automatically logs errors at the
 * LOG_WARNING level.
 */
extern int ipc_put_info (int fd,const client_t *client);

/*
 * send the client counters of specified client to the client. returns
 * 0 if successful, -1 if some error occurred. the function automatically
 * logs errors at the LOG_WARNING level.
 */
extern int ipc_put_counters (int fd,const client_t *client);

/*
 * send a timestamp of when the ruleset were added. returns 0 if
 * successful, -1 if some error occurred. the function automatically
 * logs errors at the LOG_WARNING level.
 */
extern int ipc_put_uptime (int fd,uint64_t timestamp);

#endif	/* #ifndef IPC_H */
